@@ -4,6 +4,7 @@ import com.badlogic.gdx.graphics.Color
 import com.unciv.Constants
 import com.unciv.logic.civilization.Civilization
 import com.unciv.ui.images.ImageGetter
+import com.unciv.ui.screens.overviewscreen.EmpireOverviewCategories.EmpireOverviewTabState
 import com.unciv.ui.screens.overviewscreen.EmpireOverviewTab.EmpireOverviewTabPersistableData
 import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.components.KeyCharAndCode
@@ -12,7 +13,7 @@ import com.unciv.ui.components.TabbedPager
 
 class EmpireOverviewScreen(
     private var viewingPlayer: Civilization,
-    defaultPage: String = "",
+    defaultCategory: EmpireOverviewCategories? = null,
     selection: String = ""
 ) : BaseScreen(), RecreateOnResize {
     // 50 normal button height + 2*10 topTable padding + 2 Separator + 2*5 centerTable padding
@@ -38,12 +39,7 @@ class EmpireOverviewScreen(
     }
 
     init {
-        val page =
-            if (defaultPage != "") {
-                game.settings.lastOverviewPage = defaultPage
-                defaultPage
-            }
-            else game.settings.lastOverviewPage
+        val selectCategory = defaultCategory ?: game.settings.lastOverviewPage
         val iconSize = Constants.defaultFontSize.toFloat()
 
         globalShortcuts.add(KeyCharAndCode.BACK) { game.popScreen() }
@@ -57,10 +53,10 @@ class EmpireOverviewScreen(
         tabbedPager.addClosePage { game.popScreen() }
 
         for (category in EmpireOverviewCategories.values()) {
-            val tabState = category.stateTester(viewingPlayer)
+            val tabState = category.testState(viewingPlayer)
             if (tabState == EmpireOverviewTabState.Hidden) continue
             val icon = if (category.iconName.isEmpty()) null else ImageGetter.getImage(category.iconName)
-            val pageObject = category.factory(viewingPlayer, this, persistState?.get(category))
+            val pageObject = category.createTab(viewingPlayer, this, persistState?.get(category))
             pageObject.pad(10f, 0f, 10f, 0f)
             pageObjects[category] = pageObject
             val index = tabbedPager.addPage(
@@ -71,7 +67,7 @@ class EmpireOverviewScreen(
                 shortcutKey = category.shortcutKey,
                 scrollAlign = category.scrollAlign
             )
-            if (category.name == page) {
+            if (category == selectCategory) {
                 tabbedPager.selectPage(index)
                 select(pageObject, selection)
             }
